ProjectedDistance: ProjectedDistance

Description Usage Arguments Value Examples

Description

This function estimates the projected distances between galaxies needed for the estimation of the virial radius of the galaxy cluster.

Usage

1

Arguments

cat

data frame with a the angular coordinates (ra and dec in radians) and the redshift. The columns must be named 'ra', 'dec' and 'z'.

Value

sum(1/d) where d is a vector with the projected distances.

Examples

1

Martindelosrios/MeSsI documentation built on May 14, 2021, 3:43 p.m.