Description Usage Arguments Value Examples
This function estimates the projected distances between galaxies needed for the estimation of the virial radius of the galaxy cluster.
1 |
cat |
data frame with a the angular coordinates (ra and dec in radians) and the redshift. The columns must be named 'ra', 'dec' and 'z'. |
sum(1/d) where d is a vector with the projected distances.
1 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.